pub fn from_generated_protocol_frame(
frame: ProtocolFrame,
) -> Result<ProtocolFrame, ProtocolCodecError>Expand description
Convert the generated wire frame into the compatibility protocol frame.
pub fn from_generated_protocol_frame(
frame: ProtocolFrame,
) -> Result<ProtocolFrame, ProtocolCodecError>Convert the generated wire frame into the compatibility protocol frame.