pub fn to_generated_protocol_frame(
frame: &ProtocolFrame,
) -> Result<ProtocolFrame, ProtocolCodecError>Expand description
Convert the compatibility protocol frame into the generated wire frame.
pub fn to_generated_protocol_frame(
frame: &ProtocolFrame,
) -> Result<ProtocolFrame, ProtocolCodecError>Convert the compatibility protocol frame into the generated wire frame.